==> 3050-PostSoftwareAssuranceTool-1.1.0-1.zip: ReportListDlg.h <==
#if !defined(AFX_REPORTLISTDLG_H__64F3A816_D535_469C_912F_81634F596DE0__INCLUDED_)
#define AFX_REPORTLISTDLG_H__64F3A816_D535_469C_912F_81634F596DE0__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// ReportListDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CReportListDlg dialog

class CReportListDlg : public CDialog
{
// Construction
public:
	CReportListDlg(CWnd* pParent = NULL);   // standard constructor
	void SetSocket( CClientSocket* pClientSocket );
	void SetWnd(HWND hwnd);
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );

// Dialog Data
	HWND			m_pHwnd;
	int				m_nListIndex;
	CString			m_strProgramKey;
	CClientSocket*	m_pClientSocket;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	BOOL			m_bIsFirst;
	
//enum { IDD = IDD_REPORT_LIST_DIALOG 240 };
	//{{AFX_DATA(CReportListDlg)
	enum { IDD = 240 };
	CListCtrl	m_listReport;
	CEdit	m_edtReadContent;
	YButton	m_btnRightList;
	YButton	m_btnLeftList;
	YButton	m_btnClose;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CReportListDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CReportListDlg)
	afx_msg void OnButtonClose();
	afx_msg void OnButtonLeftMove();
	afx_msg void OnButtonRightMove();
	afx_msg void OnPaint();
	virtual BOOL OnInitDialog();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_REPORTLISTDLG_H__64F3A816_D535_469C_912F_81634F596DE0__INCLUDED_)

==> 3050-PostSoftwareAssuranceTool-1.2.1-1.zip: ReportListDlg.h <==
#if !defined(AFX_REPORTLISTDLG_H__64F3A816_D535_469C_912F_81634F596DE0__INCLUDED_)
#define AFX_REPORTLISTDLG_H__64F3A816_D535_469C_912F_81634F596DE0__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// ReportListDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CReportListDlg dialog

class CReportListDlg : public CDialog
{
// Construction
public:
	CReportListDlg(CWnd* pParent = NULL);   // standard constructor
	void SetSocket( CClientSocket* pClientSocket );
	void SetWnd(HWND hwnd);
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	void GivenReceiveData ( KReportListPacket* pPacket );
	CString ParsingDate( char* pszDate );
	void InitListCtrl();
// Dialog Data
	HWND			m_pHwnd;
	int				m_nListIndex;
	CString			m_strProgramKey;
	CClientSocket*	m_pClientSocket;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	BOOL			m_bIsFirst;
	
//enum { IDD = IDD_REPORT_LIST_DIALOG 240 };
	//{{AFX_DATA(CReportListDlg)
	enum { IDD = 240 };
	CStatic	m_staticReadContent;
	CListCtrl	m_listReport;
	CEdit	m_edtReadContent;
	YButton	m_btnRightList;
	YButton	m_btnLeftList;
	YButton	m_btnClose;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CReportListDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CReportListDlg)
	afx_msg void OnButtonClose();
	afx_msg void OnButtonLeftMove();
	afx_msg void OnButtonRightMove();
	afx_msg void OnPaint();
	virtual BOOL OnInitDialog();
	afx_msg void OnItemclickList1(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnClickList1(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg HBRUSH OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_REPORTLISTDLG_H__64F3A816_D535_469C_912F_81634F596DE0__INCLUDED_)
